/*
 *  Copyright (c) 2018 VMware, Inc. All rights reserved.
 *  This product is protected by copyright and intellectual property laws in  the United States
 *  and other countries
 *  as well as by international treaties.
 *  VMware products may be covered by one or more patents listed at
 *  http://www.vmware.com/go/patents.
 */
package com.airwatch.sdk

import android.app.NotificationChannel
import android.app.NotificationChannelGroup
import android.app.NotificationManager
import android.content.Context
import android.os.Build
import android.support.annotation.RequiresApi
import android.support.annotation.VisibleForTesting
import com.airwatch.sdk.AirWatchSDKConstants.*
import com.airwatch.sdk.wrapper.R


/**
 * This class is a wrapper class of system notification manager for Android Oreo and above.
 * It includes add/delete sso and admin notification channel for sdk
 */
@RequiresApi(Build.VERSION_CODES.O)
class AWNotificationChannelPostOManager(private val appContext: Context) {
    var manager: NotificationManager = appContext.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager

    /**
     * Create notification channel for {@param id}, and set importance level, if the channel already exist, do nothing
     * Add the channel into group "Other"
     * @param id id of the new notification channel
     * @param name name of the new notification channel
     * @param importance importance level
     */
    fun createNotificationChannel(id: String, name: String, description: String, importance: Int) {
        val channelNew = NotificationChannel(id, name, importance)
        channelNew.description = description
        manager.createNotificationChannel(channelNew)
    }

    private fun createNotificationGroup(id: String, name: String) {
        val group = NotificationChannelGroup(id, name)
        manager.createNotificationChannelGroup(group)
    }

    /**
     * delete the notification channel if exist.
     * @param channelID id of the channel.
     */
    fun delete(channelID: String) {
        manager.deleteNotificationChannel(channelID)
    }

    /**
     * delete all SDK notification channel and channel group if exist.
     */
    @VisibleForTesting
    fun deleteAll() {
        manager.deleteNotificationChannel(SSO_CHANNEL)
        manager.deleteNotificationChannel(ADMIN_CHANNEL)
    }
}
