/*
 * AirWatch Android Software Development Kit
 * Copyright (c) 2013 AirWatch. All rights reserved.
 *
 * Unless required by applicable law, this Software Development Kit and sample
 * code is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 * ANY KIND, either express or implied. AirWatch expressly disclaims any and all
 * liability resulting from User's use of this Software Development Kit. Any
 * modification made to the SDK must have written approval by AirWatch.
 */

package com.airwatch.sdk;

import java.util.List;

import com.airwatch.bizlib.model.CertificateDefinition;
import com.airwatch.sdk.ICertificateReceiver;
import android.os.ResultReceiver;
import android.os.Bundle;
import android.content.Intent;

interface IAirWatchSDKService {
    // Service Information
    int getAPIVersion();
    String getDeviceUid();
    boolean hasAPIPermission();
    int isEnrolled();
    String getServerName();
    String getGroupId();
	
    // Authentication
    int getAuthenticationType();
    int authenticateUser(String userName, String userPassword);

    String getPasscodePolicy();
    int setPasscode(String passcode);
    int validatePasscode(String passcode);
    int resetPasscode();
    
    // Device Compliance
    int isCompliant();
    int isCompromised();
    int isEnterprise();
    
    // Restrictions
    String getRestrictionPolicy();

    // Application Configuration Management
    String getApplicationProfile();
    int reportApplicationProfile(String id, boolean isUsed);
    
    // Statistics
    int reportAnalytics(String analytics);

    // v2 APIs

    // Do Not Disturb APIs
    int isDNDEnabled();
    int getDNDStatus(); 
    int setDNDStatus(boolean state);

    // Auto Enrollment APIs
    int autoEnroll(String server, String groupId, String user, String password);
    int autoUnenroll();
    
    // Single Sign On APIs.
    int isSSOSessionValid();
    int createSSOSession();
    int isSSOActivated();
    int getSSOGracePeriod();
    int getSSORemainingGracePeriod();
    int isSSOEnabled();
    String getIntegratedAuthenticationProfile();
    
    // For Demo only. Need to remove these APIs.
    int setSSOActivated(boolean status); // can be hidden. No need to expose this.
    // Demo APIs end
    
    //SharedDevice API START
    String checkOutDevice(String user,String password,String groupCode);
    String acceptCheckoutEULA(String eulaContentId ,boolean  accepted);
    int checkInDevice();
    String getSharedDeviceStatus();
    //SharedDevice API END
    
    // Application Information
    String register(String publicKey, String appId, boolean reRegister);
    String getEnrollmentUsername(String publicKey);
    String getEnrollmentPassword(String publicKey);
    String getUserId(String publicKey);
    
    // Service Information 2
    float getConsoleVersion();
    String getAnchorAppStatus();
    
    // Session Token  Across Application
    String getSessionToken(int type);
    int setSessionToken(int type , String sessionToken);
    
    // Certificate APIs
    CertificateDefinition getAuthCertificate(String hostname);

    // Custom Settings
    String getCustomSettings();
        
    //Enterprise reset/wipe
    void requestEnterpriseWipe();
    void requestEnterpriseReset();
    
    // Custom Profile XML
    boolean registerProfileListener(String type);
    List<String> getProfileGroupJSONByType(String type);
    String getProfileGroupJSONByUUID(String uuid);
    
	// Factory reset device
	void requestFactoryReset();
	
	// Remove Profiles
	List<String> getAllProfiles();
	boolean removeProfile(String profileName);
	
	// Reboot device
	void rebootDevice();

	//Logging API
	int uploadApplicationLogs(in ParcelFileDescriptor pfd);
	String getLoggingSettings();
	int sendAppDataForDiagnosticLog(String appData);

	String getKrbToken(String spn);
	
	//Last Device Checkin Time
	long getDeviceLastCheckinTime();

	//Checking for Wifi SSID restriction
	int isAllowedSSID();

	//Certificate sharing based on IssuerId and token
	int requestCertificates(String issuerId, String token, ICertificateReceiver receiver);

	String getKerberosToken(String jsonString);
	
	//Whitelisted apps for the Airwatch VPN Client
	List<String> getWhitelistedAppsForVPNProfileUUID(String uuid);
	String getAppConfigJSONbyPkgId(String packageName);

	// Cert Pinning for MAG - Wrapped Apps
    String getMagCertificateKeys();

    int isBroadcastTokenValid(String encMsg);

    String getApplicationConfigSetting();

    // Saving package Name on service connection for sharedUserId cases
    void saveSharedUIDPackageName(String packageName);

   // Update application forground status
    void updateAppForgroundStatus(String packageName);

    Bundle getApplicationConfiguration();

    // Secure Launcher calls for upgrade
    void startSecureLauncherUpgrade();

    boolean updateEnrollmentCredentials(String user, String pass);
    int getServerPort();

    String getSDKProfileJSON();

    boolean registerSDKProfileUpdateListener();
    
    boolean isPasscodePromptRequired();

    //  LOCKED  2  UNLOCK  1  UN_INIT = 0
    int getApplicationState();

    //Direct Enrollment
    boolean performDirectAgentEnrollment(String directEnrollmentUrl, String directEnrollmentToken,
            in Intent onSuccessIntent, in Intent onErrorIntent);

    Bundle getClientAppInfo(String packageName);

    boolean takeApplicationAction(in Bundle bundle, in ResultReceiver listener);

    //CICO Launcher
    void performSharedDeviceOperation(in Bundle bundle, in ResultReceiver receiver);

    int getHubAuthenticationMode();

}
