/*
 * Copyright (c) 2019 AirWatch, LLC. All rights reserved.
 *  This product is protected by copyright and intellectual property laws in  the United States and other countries
 *  as well as by international treaties.
 *  AirWatch products may be covered by one or more patents listed at
 *  http://www.vmware.com/go/patents.
 */

package com.airwatch.sdk.shareddevice

import android.os.Bundle
import android.os.Handler
import android.os.Looper
import android.os.ResultReceiver

/**
 * This class provides the result of the specified share device operation
 * The result bundle must contain the operation type (i.e checkout or checkin) and any resultData if necessary
 */

class SharedDeviceResultReceiver(val sharedDeviceResultReceiverCallback: ResultReceiverCallBack) : ResultReceiver(Handler(Looper.getMainLooper())) {

    override fun onReceiveResult(resultCode: Int, resultData: Bundle?) {
        if (resultCode == RESULT_SUCCESS) {
            sharedDeviceResultReceiverCallback.onSuccess(resultData)
        } else if (resultCode == RESULT_FAILURE)
            sharedDeviceResultReceiverCallback.onError(resultData)
    }

    interface ResultReceiverCallBack {
        fun onSuccess(resultData: Bundle?)
        fun onError(resultData: Bundle?)
    }

    companion object {
        const val RESULT_SUCCESS = 200
        const val RESULT_FAILURE = 400
        const val USERNAME = "username"
        const val PASSWORD = "password"
        const val GROUP_ID = "group_id"
        const val CLEAR_APP_DATA_ON_LOGOUT = "clear_app_data_on_logout"
        const val SHARED_DEVICE_OPERATION = "operation"
        const val CHECKIN_RESULT_CODE = "checkin_result_code"
    }
}